@@ -1,16 +1,23 @@
 """
 Definition of the constants of the module
 """
+from methodtools import lru_cache
+
 from .client import Client, LAST_MODIFIED as last_modified
 
 EMPTY = "empty"
 
 FUTURE_TYPE = "Future"
 
-try:
-    FUTURES, _ = Client().get_tickers()
-except:  # pylint: disable=bare-except
-    FUTURES = {}
+
+@lru_cache()
+def get_futures():
+    """
+    Get the futures.
+    """
+    futures, _ = Client().get_tickers()
+    return futures
+
 
 LAST_MODIFIED = last_modified
 
