@@ -6,7 +6,7 @@ from datetime import date, datetime, timedelta
 from methodtools import lru_cache
 
 from ..data.client import Client
-from ..data.constants import FUTURES
+from ..data.constants import get_futures
 
 
 class Contract:
@@ -14,6 +14,8 @@ class Contract:
     Contract management.
     """
 
+    # pylint: disable=too-many-instance-attributes
+
     def __init__(
         self,
         ric: str = None,
@@ -91,8 +93,11 @@ class Contract:
             is_recent_ric = year >= (date.today() - timedelta(days=365)).year
         return is_recent_ric
 
-    def __get_contract(self, ticker: str, day: date, contract_rank: int = 0):
+    @staticmethod
+    def __get_contract(ticker: str, day: date, contract_rank: int = 0):
         chain = Contract(ticker=ticker, day=day).chain
+        if chain is None:
+            return None, None
         contract = chain.iloc[contract_rank, :]
         ltd = datetime.strptime(contract.LTD, "%Y-%m-%d").date()
         ric = contract.RIC
@@ -123,7 +128,7 @@ class Contract:
         if self.ticker is None or self.day is None:
             return None, None
 
-        future = FUTURES.get(self.ticker, {})
+        future = get_futures().get(self.ticker, {})
         roll_offset_from_reference = timedelta(
             days=future.get("RollOffsetFromReference", -31)
         )
@@ -153,7 +158,7 @@ class Contract:
             str
                 RIC.
         """
-        future = FUTURES.get(self.ticker, {})
+        future = get_futures().get(self.ticker, {})
         roll_offset_from_reference = timedelta(
             days=future.get("RollOffsetFromReference", -31)
         )
@@ -190,8 +195,10 @@ class Contract:
             stem_wo_month = stem_wo_year[:-1]
             if stem_wo_month in ["SIRT"]:
                 return "SI"
-            for ticker in FUTURES.keys():
-                if stem_wo_month == FUTURES[ticker].get("Stem", {}).get("Reuters"):
+            for ticker in get_futures().keys():
+                if stem_wo_month == get_futures()[ticker].get("Stem", {}).get(
+                    "Reuters"
+                ):
                     self._ticker = ticker
         return self._ticker
 
@@ -210,6 +217,8 @@ class Contract:
         """
         if self._first_trade_date is None:
             chain = Contract(ticker=self.ticker, day=date(1990, 1, 1)).chain
+            if chain is None:
+                return None
             if "^" in self.ric:
                 contracts = chain.loc[chain.RIC == self.ric, "FTD"]
                 if contracts.shape[0] == 0:
@@ -247,6 +256,8 @@ class Contract:
         """
         if self._last_trade_date is None:
             chain = Contract(ticker=self.ticker, day=date(1990, 1, 1)).chain
+            if chain is None:
+                return None
             if "^" in self.ric:
                 contracts = chain.loc[chain.RIC == self.ric, "LTD"]
                 if contracts.shape[0] == 0:
@@ -289,10 +300,14 @@ class Contract:
         """
         minimum_time_to_expiry = 0
         dfm, _ = Contract.__get_expiry_calendar(self.ticker)
+        if dfm is None:
+            return None
         if datetime.strptime(
             dfm.LTD.iloc[-1], "%Y-%m-%d"
         ).date() - self.day < timedelta(days=minimum_time_to_expiry):
-            expiry_calendar = FUTURES.get(self.ticker, {}).get("ExpiryCalendar", "")
+            expiry_calendar = (
+                get_futures().get(self.ticker, {}).get("ExpiryCalendar", "")
+            )
             raise Exception(
                 f"Not enough data for {self.ticker}. Download expiry data from {expiry_calendar}"
             )
@@ -332,7 +347,7 @@ def stem_to_ticker(stem: str):
             Ticker.
     """
     tickers = [
-        k for k, v in FUTURES.items() if v.get("Stem", {}).get("Reuters") == stem
+        k for k, v in get_futures().items() if v.get("Stem", {}).get("Reuters") == stem
     ]
     if len(tickers) != 1:
         raise Exception(
